****************************************************************************
****************************************************************************
*****       UNU-WIDER/ATI Bottom-up tax gap toolkit				   *****
****************************************************************************
****************************************************************************

 
* Made by: Kwabena Adu-Ababio (kwabena@wider.unu.edu), Sebastian Castillo (), 
* Mostafa Bahbah and Amina Ebrahim

* Early version built on:  	25/01/24

* This version builds on:	28/06/24

* This do file: Tune the Machine Learning model and implements a prediction model for tax gap analysis
*							 

  /*Spell out the changes.....*/
* Edited: 25/01/24 by Sebastián: Started toolkit commands
* Edited: 28/06/24 by Sebastián: Corrected 
* Edited: DD/MM/YY by "": ........
*							 

/*------------------------------------------------------------------------------

Estimating Tax Gap Codes

Bottom-up approach to estimate a Tax Gap

Written by Sebastián Castillo, Kwabena Adu-Ababio, and Amina Ebrahim
------------------------------------------------------------------------------*/


/*------------------------------------------------------------------------------

First Stage:Stata Environment Setup 

1. Install and Update Necessary Packages
2. Preparing Stata Environment
3. Setting Up Global Directory Paths
4. Importing Data
------------------------------------------------------------------------------*/

* General: Comments/code lines requiring edits in GREEN

/// 1. Install and Update Necessary Packages

ssc install rforest	// It is necessary to install this program in order to run the Machine Learning model.

/// 2. Preparing Stata Environment
set more off
clear all
clear matrix
set linesize 200
set matsize 800
cap log close
version 14	/* Use Stata Version 14 */

/// 3. Setting Up Global Directory Paths

global dir "C:\Users\<YOUR PATH>\"

global data     "$dir\Data"
global graphs   "$dir\Graphs"
global xlsout   "$dir\Excel"
global dopath   "$dir\Dofile"
global results  "$dir\Results"
global log      "$dir\Log"

/// 4. Importing Data

use "$data/ZZ"	// Insert the database to use

/*------------------------------------------------------------------------------
Second Stage:
Choosing the model of Machine Learning 

*note: The procedure is Random forest. The code follows Schonlau and Zou (2020) 
------------------------------------------------------------------------------*/


// Before running the ML model, we need to choose two critical parameters. The first is the number of iterations in each forest branch, and the second is the number of independent variables randomly selected in each split.

generate reg_audit = (region == YY | region == TT)	// Insert "region" as the variable identifying the area where audits were conducted. YY and TT are the "values" of the region variable. For example, if a country has 4 regions: CC, BB, NN, and MM, but only we have audit data from the first three, the command must be: generate reg_audit = (region ==CC | region == BB | region == NN). Notice that, if the variable region is composed by names, you must include " ". In the example, this means a code as: generate reg_audit = (region =="CC" | region == "BB" | region == "NN")

generate evaded = XX	// Insert XX as the variable that compasses the taxes that taxpayers do not pay to estimate the gap (VAT, CIT, or PIT). Generally, this is found by auditing. This variable cannot have missing values.

keep if evaded !=. & reg_audit==1 // We keep only the audited periods in audited tax regions to choose the model.

// We need to divide the sample into two parts: a training sample and a testing sample. In the training sample, we run the model, while in the testing sample, we assess the accuracy of the predictions. It is important that each sample contains non-missing observations for the evasion variable. To create these samples, we use the command "splitsample." This code generates a variable named "u," which takes on values of 1 and 0 to distinguish between the two samples. Additionally, the code ensures that both samples maintain a balance in the evasion variable, so they have similar statistics (for example, the mean) for this variable.

set seed 201807		// We create a seed to separate the sample, ensuring consistent training and testing groups each time we run the code.
splitsample, gen(u) split(1 1) balance(evaded) rround	// We split the sample in balanced way.
sort u, stable		// Sorting the indicator variable.

// Based on the random variable, the testing sample will be between 1 and nn, and the testing sample will be nn+1 and NN. It would be best to choose nn as a percentage of NN; NN; for example, nn = 50% of NN. Our recommendation is to split the sample into 50% for testing and 50% for training.

/* Note: We will tune a predictive model to estimate non-collected taxes, specifically VAT, CIT, or PIT. In this context, the variable we want to predict is the tax amount, and we will use other relevant variables for this purpose. These variables can include any information related to the individual or entity in question (e.g., a firm or a person).

The methodology will assess the relevance of each variable, identifying the most important ones for accurate predictions. For example, if you have access to the complete forms filled out by agents regarding tax, industry, business, and geographical information, you can leverage all these variables to enhance your prediction's accuracy. The algorithm will determine the "weight" of each variable automatically. Some variables may turn out to be irrelevant; in such cases, their weight will be zero.

The model's effectiveness in predicting tax misreporting will guide these weight assignments. If you already know that a particular variable is non-informative, you can choose to omit it from your analysis. However, it is advisable to include as much relevant information as possible that you believe could assist in predicting the uncollected tax. Do keep in mind that incorporating a large number of variables may slow down the estimation process, as each variable must be evaluated.

In the code, we use the notation /VARIABLES/ to refer to the set of variables that help us to make a more accurate prediction.

*/

/*------------------------------------------------------------------------------
Step one

Tuning the first parameter: Number of iteration

------------------------------------------------------------------------------*/


/* In the following, we estimate the first critical parameter, the number of iterations.
To do that, we use the command rforest. 
We run "evaded" against the set of relevant variables to capture the best combination of variables to accuratelly predict the non-paid tax. Remember that the method will choose relevant variables, so you can incorporate as much as you want, considering that this affects the estimation time.
*/ 

generate out_of_bag_error1 = .	// Auxiliary variable for the prediction error in the training sample.
generate validation_error = .	// Auxiliary variable for the prediction error in the testing sample.
generate iter1 = .	// Auxiliar variable for the iteration process. 
local j = 0		// Creating auxiliary variable.

scalar t1 = c(current_time)		// This is to measure the time in this step.

forvalues i = 10(5)500{
local j = `j' + 1
rforest evaded /VARIABLES/ if u==1, type(reg) iter(`i') numvars(1)
quietly replace iter = `i' in `j'
quietly replace out_of_bag_error1 = `e(OOB_Error)' in `j'
predict pred if u==0
quietly replace validation_error = `e(RMSE)' in `j'
drop pred
}

scalar t2 = c(current_time)

display (clock(t2, "hms") - clock(t1, "hms")) / 1000 " seconds"		// This displays the time spent in the first estimation.

label variable out_of_bag_error1 "Out-of-bag error"
label variable iter1 "Iterations"
label variable validation_error "Validation RMSE"

// In the following plot, we see the out-of-bag error and the validation error. The number of iterations is chosen depending on when both variables stabilize. 
// For example, if after 300 iterations, both variables oscillate around some number, you can choose 300 as the critical number to iteration (or) whatever number larger than 300.

graph twoway (scatter out_of_bag_error1 iter1, mcolor(blue) msize(tiny)) (scatter validation_error iter1, mcolor(red) msize(tiny))
graph save Graph "$graphs/ml_iter.gph", replace
graph export "$graphs/ml_iter.pdf", as(pdf) replace


/*------------------------------------------------------------------------------
Step two

Tuning the second parameter: Number of variables to use in each split

------------------------------------------------------------------------------*/


/* Now, we estimate the second critical parameter, the number of variables to change in each split.
We run the same model but iterate over the number of variables. Let us suppose that the number of variables is VV. you need to put in iter the optimal number, we assume is 300 but you need to fill with what you obtained.
The testing sample will be between 1 and nn, and the testing sample will be nn+1 and NN. It would be best to choose nn as a percentage of NN; for example, nn = 80% oh NN.  
*/ 


generate oob_error = . 	// Auxiliary variable for the prediction error in the training sample.
generate nvars = .		// Auxiliary variable for the number of variables that are chosen in each split.
generate val_error = .	// Auxiliary variable for the prediction error in the testing sample.
local j = 0

capture frame drop mydata2
scalar t3 = c(current_time)

forvalues i = 1(1)VV{
local j = `j' + 1
rforest evaded /VARIABLES/ if u==1, type(reg) iter(300) numvars(`i')
quietly replace nvars = `i' in `j'
quietly replace oob_error = `e(OOB_Error)' in `j'
predict pre if u==0
quietly replace val_error = `e(RMSE)' in `j'
drop pre
}

scalar t4 = c(current_time)

display (clock(t4, "hms") - clock(t3, "hms")) / 1000 " seconds"


label variable oob_error "Out-of-bag error"
label variable val_error "Validation RMSE"
label variable nvars "Number of variables randomly selected at each split"

//The following lines of code will generate the message: "Minimum Error: XX; Corresponding Number of Variables: YY." This message provides a simplified view of the second critical parameter, which is "the corresponding number of variables (YY)." Please take note of this number for use when estimating the model. 

frame put val_error nvars, into(mydata2)

frame mydata2{
	sort val_error, stable
	local min_val_err = val_error[1]
	local min_nvars = nvars[1]
}

frame drop mydata2
display "Minimum Error: `min_val_err'; Corresponding number of variables `min_nvars'" // This number is the second relevant parameter.


// In the following plot, we see the out-of-bag error and the validation error. The critical number is chosen by looking at the iteration that minimizes the error in the testing sample. 
// For example, if at iteration 20, the minimum error is obtained, you need to choose 20 as the critical number. Before plotting, we will introduce a code that shows you the number of iterations that minimize the error and the value of the error.

graph twoway (scatter oob_error nvars, mcolor(blue) msize(tiny)) (scatter val_error nvars, mcolor(red) msize(tiny))
graph save Graph "$graphs/ml_var.gph", replace
graph export "$graphs/ml_var.pdf", as(pdf) replace

/*------------------------------------------------------------------------------
Third Stage

Testing the model

*Note: the comparison is an OLS using the same variables. The focus is on the RMSE. 
------------------------------------------------------------------------------*/

// Let us assume that the critical variables are 300 and 20, but you need to change for the optimal number that you obtained.

capture frame drop mydata2
scalar t5 = c(current_time)

rforest evaded /VARIABLES/ if u==1, type(reg) iter(300) numvars(20)

scalar t6 = c(current_time)

display (clock(t6, "hms") - clock(t5, "hms")) / 1000 " seconds"


ereturn list OOB_Error
scalar oob_error = `e(OOB_Error)'


predict tot_pred	// We predict the values for all the sample

corr evaded tot_pred if u==1 
scalar r_ml = `r(rho)'
di r(rho)^2	// We obtain the r square for the prediction in the training data


predict pre if u==0	// We predic thte values only for the testing data
ereturn list RMSE
scalar rmse_ml = `e(RMSE)'


corr evaded pre if u==0 
scalar r_ml2 = `r(rho)'
di r(rho)^2		//  We obtain the r square for the prediction in the testing data

					     
// The following code calculates the relevance index for each variable in your model. Ultimately, you can choose which variables to plot based on a specified minimum index level.

matrix importance2 = e(importance)
svmat importance2
generate importid2=""

local min_importance = ii
local mynames: rownames importance2
local k: word count `mynames'

if `k'>_N {
 set obs `k'
}

forvalues i = 1(1)`k' {
    local aword: word `i' of `mynames'
    local alabel: variable label `aword'
    if ("`alabel'"!="") qui replace importid2= "`alabel'" in `i'
    else quietly replace importid2= "`aword'" in `i'
}

// We plot the relevance of each variable. The most relevant variables have an index close to 1. However, you can choose the lower limit to the plot; in this case, we put all; you need to change this for a number between 0 and 1. 

graph hbar (mean) importance2 if importance2 > `min_importance', over(importid2, sort(1) label(labsize(2))) ytitle(Importance) note("Only variables with an importance score larger than `min_importance' % are reported.")
graph save Graph "$graphs/ml_var_rel.gph", replace
graph export "$graphs/ml_var_rel.pdf", as(pdf) replace

* With the following command, we save the index for each variable. With this information, you can analyze how relevant are each variable used in your model to predict the non-paid tax.

putexcel set "$xlsout/ml_var_rel_tot.xlsx", replace
putexcel A3 = matrix(importance2), rownames nformat(number_d2)


/*-----------------------------------------

Comparison with the regression model

-------------------------------------------*/

quietly regress evaded /VARIABLES/ if u==1
ereturn list r2	// We obtain the r square to compare with the ML in the training data
scalar r_ols = `e(r2)'
scalar rmse_ols = `e(rmse)'

predict ev in if u==0
ereturn list rmse // We obtain the rmse in the testing data


corr evaded ev if u==0
scalar r_ols2 = `r(rho)'
di r(rho)^2	// We obtain the r square to compare with the ML in the training data


generate diff_sqr2= (evaded - ev)^2
summarize diff_sqr2
scalar rmse_ols2 = `r(mean)'


summarize evaded if u==1
scalar tra_mean = `r(mean)'
scalar sd = `r(sd)'

summarize evaded if u==0
scalar tes_mean = `r(mean)'
scalar sd2 = `r(sd)'

** The above calculation compares the benefits of following the ML approach instead of a regression (OLS). This code create the table comparing R-square and RMSE from training and testing data.

collect clear

collect get row1 = oob_error, tags(col1[ML])

collect get row1 = rmse_ols, tags(col1[OLS])

collect get row2 = oob_error/tra_mean, tags(col1[ML])

collect get row2 = rmse_ols/tra_mean, tags(col1[OLS])

collect get row3 = oob_error/sd, tags(col1[ML])

collect get row3 = rmse_ols/sd, tags(col1[OLS])

collect get row4 = r_ml^2, tags(col1[ML])

collect get row4 = r_ols, tags(col1[OLS])

collect get row5 = tra_mean, tags(col1[ML])

collect get row5 = tra_mean, tags(col1[OLS])

collect get row6 = sd, tags(col1[ML])

collect get row6 = sd, tags(col1[OLS])

collect layout (result) (col1)


collect get row1 = rmse_ml, tags(col2[ML])

collect get row1 = sqrt(rmse_ols2), tags(col2[OLS])

collect get row2 = rmse_ml/tes_mean, tags(col2[ML])

collect get row2 = sqrt(rmse_ols2)/tes_mean, tags(col2[OLS])

collect get row3 = rmse_ml/sd2, tags(col2[ML])

collect get row3 = sqrt(rmse_ols2)/sd2, tags(col2[OLS])

collect get row4 = r_ml2^2, tags(col2[ML])

collect get row4 = r_ols2^2, tags(col2[OLS])

collect get row5 = tes_mean, tags(col2[ML])

collect get row5 = tes_mean, tags(col2[OLS])

collect get row6 = sd2, tags(col2[ML])

collect get row6 = sd2, tags(col2[OLS])

collect layout (result) (col2)


collect label levels result row1 "RMSE" row2 "RMSE/Mean (evasion)" row3 "RMSE/Std (evasion)" row4 "R-square" row5 "Mean (evasion)" row6 "Std (evasion)"
 
collect label dim col1 "Training"

collect label dim col2 "Test"

collect style header col1, title(label)

collect style header col2, title(label)

collect style column, dups(center)

collect style cell cell_type[corner], border(right, pattern(nil))

collect style cell col1#cell_type[column-header], border(bottom, pattern(single))

collect style cell col2#cell_type[column-header], border(bottom, pattern(single))

collect style cell result, border(right, pattern(nil))

collect title "Table. Summary Statistics"

collect style title, smcl(input)
 
collect layout (result) (col1 col2)

collect export "$xlsout/stats_comparison.xlsx"

// Graphs to see the accuracy of the preduction

/*
We will create two plots and save them in the designated folder. The first plot compares the prediction frequencies with the observed data from the testing sample. This focuses on the number of predictions in each bin, providing insight into the prediction's accuracy in terms of magnitude—specifically, the number of correct estimations compared to the actual values. 

The second plot illustrates the specific values of the predictions across the entire sample. This plot highlights the overlap between the predicted values and the actual values of the evasion variable.
*/

** Histogram of distribution of values to compare prediction vs real values in the training data. Note: yo need to change the monetary value for your own currency when says "xtitle("Monetary Value")", for instance "Euros" or "Mill Euros". 

graph twoway (histogram tot_pred if u==0, percent bin(100)) (histogram evaded if u==0, percent bin(100) fcolor(purple%30) lcolor(purple%30)), xtitle("Monetary Value") legend(order(1 "Prediction" 2 "Recovered VAT"))
graph save Graph "$graphs/histogram_prediction1.gph", replace
graph export "$graphs/histogram_prediction1.pdf", as(pdf) replace


** Scaterplot comparing prediction vs real values. "tax_vle" is the variable about the tax delcared and is used to compare the prediction and the real tax recovered, you need to change this variable for the corresponding in your data. Note: yo need to change the monetary value for your own currency when says "xtitle("Monetary Value")", for instance "Euros" or "Mill Euros".

graph twoway (scatter tot_pred tax_vle, sort mcolor(%50)) (scatter evaded tax_vle, sort mcolor(%50) msymbol(lgx)), legend(rows(1) position(6)) xtitle("Monetary Value") legend(order(1 "Prediction" 2 "Recovered VAT"))
graph save Graph "$graphs/histogram_prediction2.gph", replace
graph export "$graphs/histogram_prediction2.pdf", as(pdf) replace




/*------------------------------------------------------------------------------
Fourth Stage

Estimating the Tax Gap
 
------------------------------------------------------------------------------*/

* Since we work with a sample for the original dataset, we need to clear the dataset, and reload the original sample (with all the observations). In this sample is where we will proceed to predict the non-paid tax and obtain the tax gap. Please remember to save the optimal parameters obtained in step one and two.

clear

use "$data/ZZ"	// Insert the database to use

generate reg_audit = YY	// Insert YY as the indicator variable for the regions (geographical or tax administrative) where auditing was conducted.

generate evaded = XX	// Insert XX as the variable that compasses the taxes that taxpayers do not pay to estimate the gap (VAT, CIT, or PIT). Generally, this is found by auditing. This variable cannot have missing values.

//Since the command "rforest" requires that the dependent variable (in our case, "evaded") does not contain missing values, we created an indicator variable. This "indicator" variable is assigned a value of 1 if the observation is part of an audit process and does not have any missing values. By implementing this, we ensure that the code runs smoothly without any issues.

generate indicator = (evaded !=. & reg_audit==1)
generate mimic_tax = evaded
replace mimic_tax= 0 if evaded==.

// The parameters II and VV are derived from the tuning process outlined in steps one and two. Please replace II with the value found in Section 3.3 and VV with the value from Section 3.4. Additionally, ensure that you use the same variables as in the previous sections ("\VARIABLES\") to maintain the accuracy of the prediction model. 

rforest mimic_tax /VARIABLES/ if indicator==1, type(reg) iter(II) numvars(VV)
predict assessment if indicator==0 & reg_audit==1
replace assessment = evaded if indicator==1 & reg_audit==1

/*
The next command is to see if you have negative predictions. In case your evaded variable allows negative values (for example include a mistake as credits back), you can ommit this. 
*/
sum assessment, d

// If your variable evaded contains neggative values, follow this step. If not, you can ommit it.

generate assessment_2 = assessment
replace assessment_2 = 0 if assessment_2<0 // We impute that negative values are actually zero, by construction.


// The last two lines make the predictions. First, we create a prediction for the undeclared tax, named assessment. We predict this variable for the unaudited firms and period in the first line. In the second line, we replace the discovered value by auditing in the created variable (assessment). With those steps, the variable assessment encompasses the prediction of undeclared tax and the values recovered by auditing.

/*------------------------------------------------------------------------------
 Note: Since the tax collection for the period measures only the positive tax and does not account for refunds, we need to consider both aspects. In the following code, we create two variables. First, the "positive potential revenue" reflects the possibility that, despite a high assessment of misreporting, the actual tax owed could still be negative due to refunds or credits. Second, the "revenue losses" capture the assessments related to positive tax declarations, as well as the positive potential revenue for those who report a non-positive tax. 

This code can still be used even if there are negative values in the evaded measure.
------------------------------------------------------------------------------*/

generate pot_tax = assessment + tax	// We create the potential revenue for each observation.
replace pot_tax = 0 if pot_tax<0 // We set all the negative values as cero since those are refunds or credits.
generate rev_loss = assessment if tax>=0 // We create a variable for revenue losses. First, this variable equals the assessment if the declared tax is positive.
replace rev_loss = pot_tax if tax<0 & pot_tax>0	// We include in the revenue losses the extra revenue that firms initially declared refund (or credits) with positive potential revenue.
replace rev_loss = 0 if rev_loss==. // We set cero the rest of the results. Those are refunds and credits.

/*------------------------------------------------------------------------------

------------------------------------------------------------------------------*/

// We sum the variables by specific parameters (year, economic activity, geographical region, etc) to obtain the tax gap. You can choose the parameters to sum on, depending on the focus of the analysis. You need to choose the proper tax to compare.

** You need to replace the variable tax, for the tax you are estimating (VAT, CIT, PAYE). Also, the var_analysis for the group you are analysing. Remember that if you include year activity region, you will have one value for each combination. This means that if you only want to study activity across years, you need to include year and activity.

** Also, you need to decide the variable to plot and obtain the Excel summary. For example if you want to have the plot by year, you need to replace var_analysis1 for year.


// The following command saves your data. You must include the name you want to put in the new data in NAME, including the prediction on misreporting tax.

save "$data/NAME.dta", replace

*In the first code, we obtain the overall tax gap by year. Since this is the first estimation, the end of the command to create a table that stores the results ended with "replace". In the subsequent estimation, this ending must be "append". This means that the software appends the result in the same document and ends up with a unique Excel file named "results" with all your estimations. Similarly, we advise you to change the name of the grasp in the lines "$graphs/vat_gap.gph" and "$graphs/vat_gap.pdf" when you do a new estimation. Otherwise, you will replace the graph you obtained before. Our advice is to incorporate "_number" or "_analysis". For example, "vat_gap_1.gph", "vat_gap_2.gph" and so on (same for the "vat_gap.pdf"), or "vat_gap_industry.gph", "vat_gap_region.gph" and so on (same for the "vat_gap.pdf").

// If your variable evaded do not contains negative values, follow this. Otherwise, read the next set of commands.

/*
In the following sections, we will estimate, plot, and save the tax gap and its monetary value. To accomplish this, we will sum across a specific variable or group of variables, such as year, industry, or region. Our goal is to estimate the tax gap for a particular period, possibly with specific characteristics in mind.

To achieve this, we will use two commands: "preserve" and "restore". The "preserve" command saves the current data while we execute a specific command, and the "restore" command returns the data to its original state. By using these commands, we can avoid losing information and make the process more efficient.
*/ 

preserve

collapse (sum) assessment tax pot_tax rev_loss if reg_audit==1, by(year)

generate v01 = assessment+abs(tax)

generate vat_gap01 = (assessment/v01)*100
generate vat_gap02 = (rev_loss/pot_tax)*100

graph bar (mean) vat_gap01 vat_gap02, over(year) blabel(bar, size(vsmall) format(%9.2f)) legend( label(1 "TAX") ) ytitle(% of Evasion) title("Percentage of tax evaded") legend(order(1 "VAT gap with refunds" 2 "VAT gap w/o refunds"))
graph save Graph "$graphs/vat_gap_year.gph", replace
graph export "$graphs/vat_gap_year.pdf", as(pdf) replace

estpost tabstat vat_gap01 vat_gap02 , by(year) stat(max)col(stat)
esttab . using "$xlsout/results.csv", cells("max(lab(Max) fmt(%15.2fc))") noobs nonumber eqlabels(`e(labels)') varwidth(20) replace


restore


preserve

collapse (sum) assessment tax pot_tax rev_loss if reg_audit==1, by(var_analysis)

generate v01 = assessment+abs(tax)

generate vat_gap01 = (assessment/v01)*100
generate vat_gap02 = (rev_loss/pot_tax)*100


graph bar (mean) vat_gap01 vat_gap02, over(var_analysis) blabel(bar, size(vsmall) format(%9.2f)) legend( label(1 "TAX") ) ytitle(% of Evasion) title("Percentage of tax evaded") legend(order(1 "VAT gap with refunds" 2 "VAT gap w/o refunds"))
graph save Graph "$graphs/vat_gap.gph", replace
graph export "$graphs/vat_gap.pdf", as(pdf) replace

estpost tabstat vat_gap01 vat_gap02, by(var_analysis) stat(max)col(stat)
esttab . using "$xlsout/results.csv", cells("max(lab(Max) fmt(%15.2fc))") noobs nonumber eqlabels(`e(labels)') varwidth(20) append


restore


// If your variable evaded contains negative values, follow this.


preserve

collapse (sum) assessment_2 tax pot_tax rev_loss if reg_audit==1, by(var_analysis)

generate v01 = assessment_2+abs(tax)

generate vat_gap01 = (assessment_2/v01)*100
generate vat_gap02 = (rev_loss/pot_tax)*100

graph bar (mean) vat_gap01 vat_gap02, over(var_analysis) blabel(bar, size(vsmall) format(%9.2f)) legend( label(1 "TAX") ) ytitle(% of Evasion) title("Percentage of tax evaded") legend(order(1 "VAT gap with refunds" 2 "VAT gap w/o refunds"))
graph save Graph "$graphs/vat_gap.gph", replace
graph export "$graphs/vat_gap.pdf", as(pdf) replace

estpost tabstat vat_gap01 vat_gap02, by(var_analysis) stat(max)col(stat)
esttab . using "$xlsout/results.csv", cells("max(lab(Max) fmt(%15.2fc))") noobs nonumber eqlabels(`e(labels)') varwidth(20) append


restore



*Now, in case you want to obtain the nominal values for potential revenue, total tax collected, and potential revenue lost, you can do the following command. See that you must change in "ytitle(Monetary Unit)" the part "Monetary Unit" with your monetary unit, for example "US dollars". As before, we first obtain the overall results, and later by sector/industry/regions, etc. Please, follow the same advice as before concerning the name of the graphs saved.

preserve

collapse (sum) assessment tax pot_tax rev_loss if reg_audit==1, by(year)

generate potential_revenue = assessment+abs(tax)


graph bar (mean) potential_revenue assessment tax pot_tax rev_loss, over(year) blabel(bar, size(vsmall) format(%9.2f)) legend( label(1 "Potential Revenue") label(2 "Revenue Lost (predicted)") label(3 "Revenue Collected") label(4 "Potential Revenue w/o Refunds") label(5 "Revenue Lost (predicted) w/o Refunds")) ytitle(Monetary Unit) title("Revenue Consequences") 
graph save Graph "$graphs/revenue_gap.gph", replace
graph export "$graphs/revenue_gap.pdf", as(pdf) replace

estpost tabstat potential_revenue assessment tax pot_tax rev_loss , by(year) stat(max)col(stat)
esttab . using "$xlsout/results_nominal.csv", cells("max(lab(Max) fmt(%15.2fc))") noobs nonumber eqlabels(`e(labels)') varwidth(20) replace


restore



preserve

collapse (sum) assessment tax pot_tax rev_loss if reg_audit==1, by(var_analysis)

generate potential_revenue = assessment+abs(tax)


graph bar (mean) potential_revenue assessment tax pot_tax rev_loss, over(var_analysis) blabel(bar, size(vsmall) format(%9.2f)) legend( label(1 "Potential Revenue") label(2 "Revenue Lost (predicted)") label(3 "Revenue Collected") label(4 "Potential Revenue w/o Refunds") label(5 "Revenue Lost (predicted) w/o Refunds")) ytitle(Monetary Unit) title("Revenue Consequences") 
graph save Graph "$graphs/revenue_gap.gph", replace
graph export "$graphs/revenue_gap.pdf", as(pdf) replace

estpost tabstat potential_revenue assessment tax pot_tax rev_loss , by(var_analysis) stat(max)col(stat)
esttab . using "$xlsout/results_nominal.csv", cells("max(lab(Max) fmt(%15.2fc))") noobs nonumber eqlabels(`e(labels)') varwidth(20) append


restore


